@@ -61,9 +61,10 @@ using namespace std;
 
 namespace libdap {
 
-Array::dimension::dimension(D4Dimension *d) : dim(d), use_sdim_for_slice(true) {
-	size = d->size();
-	name = d->name();
+Array::dimension::dimension(D4Dimension *d) : dim(d), use_sdim_for_slice(true)
+{
+    size = d->size();
+    name = d->name();
 
     start = 0;
     stop = size - 1;
