@@ -125,7 +125,7 @@ BaseType::m_duplicate(const BaseType &bt)
 BaseType::BaseType(const string &n, const Type &t, bool is_dap4)
         : d_name(n), d_type(t), d_dataset(""), d_is_read(false), d_is_send(false),
         d_parent(0), d_attributes(0), d_is_dap4(is_dap4),
-        d_in_selection(false), d_is_synthesized(false)
+		d_in_selection(false), d_is_synthesized(false)
 {}
 
 /** The BaseType constructor needs a name, a dataset, and a type.
@@ -143,7 +143,7 @@ BaseType::BaseType(const string &n, const Type &t, bool is_dap4)
 BaseType::BaseType(const string &n, const string &d, const Type &t, bool is_dap4)
         : d_name(n), d_type(t), d_dataset(d), d_is_read(false), d_is_send(false),
         d_parent(0), d_attributes(0), d_is_dap4(is_dap4),
-        d_in_selection(false), d_is_synthesized(false)
+		d_in_selection(false), d_is_synthesized(false)
 {}
 
 /** @brief The BaseType copy constructor. */
@@ -180,12 +180,11 @@ BaseType::operator=(const BaseType &rhs)
     debugging when regular inspection w/ddd or gdb isn't enough.
 
     @return A string which shows the object's internal stuff. */
-string
-BaseType::toString()
+string BaseType::toString()
 {
     ostringstream oss;
     oss << "BaseType (" << this << "):" << endl
-    << "          _name: " << d_name << endl
+    << "          _name: " << name() << endl
     << "          _type: " << type_name() << endl
     << "          _dataset: " << d_dataset << endl
     << "          _read_p: " << d_is_read << endl
@@ -240,7 +239,7 @@ BaseType::dump(ostream &strm) const
     << (void *)this << ")" << endl ;
     DapIndent::Indent() ;
 
-    strm << DapIndent::LMarg << "name: " << d_name << endl ;
+    strm << DapIndent::LMarg << "name: " << name() << endl ;
     strm << DapIndent::LMarg << "type: " << type_name() << endl ;
     strm << DapIndent::LMarg << "dataset: " << d_dataset << endl ;
     strm << DapIndent::LMarg << "read_p: " << d_is_read << endl ;
@@ -425,8 +424,11 @@ BaseType::read_p()
 
 /** Sets the value of the <tt>read_p</tt> property. This indicates that the
     value(s) of this variable has/have been read. An implementation of the
-    read() method would typically use this to set the \c read_p property to
-    true.
+    read() method should use this to set the \c read_p property to true.
+
+    @note If the is_synthesized property is true, this method will _not_
+    alter the is_read property. If you need that behavior, specialize the
+    method in your subclasses if the various types.
 
     @note For most of the types the default implementation of this method is
     fine. However, if you're building a server which must handle data
@@ -453,20 +455,28 @@ BaseType::read_p()
 void
 BaseType::set_read_p(bool state)
 {
-    d_is_read = state;
-
+    // The this comment is/was wrong!
     // The is_synthesized property was not being used and the more I thought
     // about how this was coded, the more this code below seemed like a bad idea.
     // Once the property was set, the read_p property could not be changed.
     // That seems a little silly. Also, I think I need to use this is_synthesized
     // property for some of the server function code I'm working on for Raytheon,
     // and I'd like to be able to control the read_p property! jhrg 3/9/15
-#if 0
-    if (! d_is_synthesized) {
-        DBG2(cerr << "Changing read_p state of " << name() << " to "
-	         << state << endl);
+
+    // What's true: The is_synthesized property is used by
+    // 'projection functions' in the freeform handler. It might be better
+    // to modify the FFtypes to support this behavior, but for now I'm returning
+    // the library to its old behavior. That this change (setting is_read
+    // of the value of is_syn...) broke the FF handler was not detected
+    // because the FF tests were not being run due to an error in the FF
+    // bes-testsuite Makefile.am). jhrg 9/9/15
+
+#if 1
+    if (!d_is_synthesized) {
         d_is_read = state;
     }
+#else
+    d_is_read = state;
 #endif
 }
 
@@ -961,7 +971,7 @@ BaseType::print_decl(ostream &out, string space, bool print_semi,
     if (constrained && !send_p())
         return;
 
-    out << space << type_name() << " " << id2www(d_name) ;
+    out << space << type_name() << " " << id2www(name()) ;
 
     if (constraint_info) {
         if (send_p())
@@ -1041,8 +1051,8 @@ BaseType::print_xml_writer(XMLWriter &xml, bool constrained)
     if (xmlTextWriterStartElement(xml.get_writer(), (const xmlChar*)type_name().c_str()) < 0)
         throw InternalErr(__FILE__, __LINE__, "Could not write " + type_name() + " element");
 
-    if (!d_name.empty())
-    if (xmlTextWriterWriteAttribute(xml.get_writer(), (const xmlChar*) "name", (const xmlChar*)d_name.c_str()) < 0)
+    if (!name().empty())
+    if (xmlTextWriterWriteAttribute(xml.get_writer(), (const xmlChar*) "name", (const xmlChar*)name().c_str()) < 0)
         throw InternalErr(__FILE__, __LINE__, "Could not write attribute for name");
 
     if (is_dap4())
@@ -1110,7 +1120,7 @@ BaseType::print_dap4(XMLWriter &xml, bool constrained)
 bool
 BaseType::check_semantics(string &msg, bool)
 {
-    bool sem = (d_type != dods_null_c && d_name.length());
+    bool sem = (d_type != dods_null_c && name().length());
 
     if (!sem)
         msg = "Every variable must have both a name and a type\n";
