@@ -58,20 +58,30 @@ void D4Group::m_duplicate(const D4Group &g)
 	if (g.d_dims) {
 		d_dims = new D4Dimensions(*(g.d_dims));
 		d_dims->set_parent(this);
+
+	    // Update all of the D4Dimension weak pointers in the Array objects.
+	    // This is a hack - we know that Constructor::m_duplicate() has been
+	    // called at this point and any Array instances have dimension pointers
+	    // that reference the 'old' dimensions (g.d_dims) and not the 'new'
+	    // dimensions made above. Scan every array and re-wire the weak pointers.
+	    // jhrg 8/15/14
+	    Vars_citer vi = d_vars.begin();
+	    while (vi != d_vars.end()) {
+	        if ((*vi)->type() == dods_array_c)
+	            static_cast<Array*>(*vi)->update_dimension_pointers(g.d_dims, d_dims);
+	        ++vi;
+	    }
 	}
 
-	// Update all of the D4Dimension weak pointers in the Array objects.
-	// This is a hack - we know that Constructor::m_duplicate() has been
-	// called at this point and any Array instances have dimension pointers
-	// that reference the 'old' dimensions (g.d_dims) and not the 'new'
-	// dimensions made above. Scan every array and re-wire the weak pointers.
-	// jhrg 8/15/14
+#if 0
+	// Moved this block up inside the if because g.d_dims might be false. jhrg 9/14/15
 	Vars_citer vi = d_vars.begin();
 	while (vi != d_vars.end()) {
 		if ((*vi)->type() == dods_array_c)
 			static_cast<Array*>(*vi)->update_dimension_pointers(g.d_dims, d_dims);
 		++vi;
 	}
+#endif
 
 	// enums; deep copy
 	if (g.d_enum_defs) d_enum_defs = new D4EnumDefs(*g.d_enum_defs);
