@@ -532,9 +532,9 @@ static const yytype_uint16 yyrline[] =
      254,   255,   254,   258,   259,   258,   262,   263,   262,   266,
      267,   266,   271,   291,   270,   299,   298,   304,   308,   314,
      318,   324,   328,   334,   338,   344,   348,   354,   358,   364,
-     368,   374,   379,   386,   390,   396,   412,   415,   418,   421,
-     421,   421,   421,   421,   422,   422,   422,   422,   423,   423,
-     423,   423,   427,   431,   426
+     368,   374,   379,   386,   390,   396,   410,   413,   416,   419,
+     419,   419,   419,   419,   420,   420,   420,   420,   421,   421,
+     421,   421,   425,   429,   424
 };
 #endif
 
@@ -1398,9 +1398,9 @@ yyreduce:
         case 2:
 #line 194 "das.yy" /* yacc.c:1646  */
     {
-		name = new string();
-		type = new string();
-		attr_tab_stack = new vector<AttrTable *>;
+		if (!name) name = new string();
+		if (!type) type = new string();
+		if (!attr_tab_stack) attr_tab_stack = new vector<AttrTable *>;
 
 		// push outermost AttrTable
 		PUSH(DAS_OBJ(arg)->get_top_level_attributes());
@@ -1412,9 +1412,9 @@ yyreduce:
 #line 203 "das.yy" /* yacc.c:1646  */
     {
 		POP;	// pop the DAS/AttrTable before stack's dtor
-		delete name;
-		delete type;
-		delete attr_tab_stack;
+		delete name; name = 0;
+		delete type; type = 0;
+		delete attr_tab_stack; attr_tab_stack = 0;
 	}
 #line 1420 "das.tab.cc" /* yacc.c:1646  */
     break;
@@ -1741,37 +1741,35 @@ yyreduce:
                     // XML must be quoted in the DAS but the quotes are an
                     // artifact of the DAS syntax so they are not part of the
                     // value.
-                    cerr << "Attr value as read: " << (yyvsp[0]) << endl;
                     string xml = unescape_double_quotes((yyvsp[0]));
-                    cerr << "w/o quotes: " << remove_quotes(xml) << endl;
                     
                     if (is_quoted(xml))
                         add_attribute(*type, *name, remove_quotes(xml), 0);
                     else
                         add_attribute(*type, *name, xml, 0);
                 }
-#line 1754 "das.tab.cc" /* yacc.c:1646  */
+#line 1752 "das.tab.cc" /* yacc.c:1646  */
     break;
 
   case 82:
-#line 427 "das.yy" /* yacc.c:1646  */
+#line 425 "das.yy" /* yacc.c:1646  */
     { 
 		    *name = (yyvsp[0]);
 		}
-#line 1762 "das.tab.cc" /* yacc.c:1646  */
+#line 1760 "das.tab.cc" /* yacc.c:1646  */
     break;
 
   case 83:
-#line 431 "das.yy" /* yacc.c:1646  */
+#line 429 "das.yy" /* yacc.c:1646  */
     {
 		    add_alias( DAS_OBJ(arg)->get_top_level_attributes(),
 		               TOP_OF_STACK, *name, string((yyvsp[0])) ) ;
                 }
-#line 1771 "das.tab.cc" /* yacc.c:1646  */
+#line 1769 "das.tab.cc" /* yacc.c:1646  */
     break;
 
 
-#line 1775 "das.tab.cc" /* yacc.c:1646  */
+#line 1773 "das.tab.cc" /* yacc.c:1646  */
       default: break;
     }
   /* User semantic actions sometimes alter yychar, and that requires
@@ -1999,7 +1997,7 @@ yyreturn:
 #endif
   return yyresult;
 }
-#line 438 "das.yy" /* yacc.c:1906  */
+#line 436 "das.yy" /* yacc.c:1906  */
 
 
 // This function is required for linking, but DODS uses its own error
@@ -2017,9 +2015,9 @@ a_or_an(const string &subject)
     string::size_type pos = first_char.find_first_of("aeiouAEIOUyY");
     
     if (pos == string::npos)
-	return "a";
+		return "a";
     else
-	return "an";
+		return "an";
 }
 
 // This code used to throw an exception when a bad attribute value came
@@ -2034,16 +2032,16 @@ add_attribute(const string &type, const string &name, const string &value,
 	<< " to Attrtable: " << TOP_OF_STACK << endl);
 
     if (chk && !(*chk)(value.c_str())) {
-	string msg = "`";
-	msg += value + "' is not " + a_or_an(type) + " " + type + " value.";
-	add_bad_attribute(TOP_OF_STACK, type, name, value, msg);
-	return;
+		string msg = "`";
+		msg += value + "' is not " + a_or_an(type) + " " + type + " value.";
+		add_bad_attribute(TOP_OF_STACK, type, name, value, msg);
+		return;
     }
     
     if (STACK_EMPTY) {
-	string msg = "Whoa! Attribute table stack empty when adding `" ;
-	msg += name + ".' ";
-	parse_error(msg, das_line_num);
+		string msg = "Whoa! Attribute table stack empty when adding `" ;
+		msg += name + ".' ";
+		parse_error(msg, das_line_num);
     }
     
     try {
@@ -2057,8 +2055,8 @@ add_attribute(const string &type, const string &name, const string &value,
 	    TOP_OF_STACK->append_attr(name, type, value);
     }
     catch (Error &e) {
-	// re-throw with line number
-	parse_error(e.get_error_message().c_str(), das_line_num);
+	 	// re-throw with line number
+		parse_error(e.get_error_message().c_str(), das_line_num);
     }
 }
 
