@@ -527,12 +527,12 @@ static const yytype_uint8 yytranslate[] =
   /* YYRLINE[YYN] -- Source line where rule number YYN was defined.  */
 static const yytype_uint16 yyrline[] =
 {
-       0,   160,   160,   160,   170,   171,   174,   178,   188,   192,
-     193,   200,   223,   222,   243,   242,   263,   275,   287,   262,
-     308,   319,   325,   331,   337,   338,   339,   340,   341,   342,
-     343,   344,   345,   348,   349,   352,   352,   352,   352,   352,
-     353,   353,   353,   353,   354,   354,   354,   354,   355,   358,
-     382,   386,   381,   413,   424,   425,   426
+       0,   160,   160,   160,   176,   177,   180,   184,   193,   196,
+     197,   206,   221,   220,   242,   241,   263,   275,   287,   262,
+     308,   318,   324,   330,   336,   337,   338,   339,   340,   341,
+     342,   343,   344,   347,   348,   351,   351,   351,   351,   351,
+     352,   352,   352,   352,   353,   353,   353,   353,   354,   357,
+     379,   383,   378,   409,   419,   420,   421
 };
 #endif
 
@@ -1386,168 +1386,167 @@ yyreduce:
         case 2:
 #line 160 "dds.yy" /* yacc.c:1646  */
     {
-		    /* On entry to the parser, make the BaseType stack. */
-		    ctor = new stack<BaseType *>;
-                }
-#line 1393 "dds.tab.cc" /* yacc.c:1646  */
+		    /* On entry to the parser, make the BaseType stack. 
+		       I use if (!ctor) here because in the tab.cc file,
+		       this is a case block in a switch, so it could be
+		       run more than once, causing the storage to be
+		       overwritten. jhrg 6/26/15 */
+		       
+		    if (!ctor)
+		    	ctor = new stack<BaseType *>;
+        }
+#line 1399 "dds.tab.cc" /* yacc.c:1646  */
     break;
 
   case 3:
-#line 165 "dds.yy" /* yacc.c:1646  */
+#line 171 "dds.yy" /* yacc.c:1646  */
     {
 		    delete ctor; ctor = 0;
 		}
-#line 1401 "dds.tab.cc" /* yacc.c:1646  */
+#line 1407 "dds.tab.cc" /* yacc.c:1646  */
     break;
 
   case 6:
-#line 175 "dds.yy" /* yacc.c:1646  */
+#line 181 "dds.yy" /* yacc.c:1646  */
     {
-		    (yyval.boolean) = (yyvsp[-3].boolean) && (yyvsp[-1].word);
+		    (yyval.boolean) = (yyvsp[-3].boolean) && (yyvsp[-1].boolean);
 		}
-#line 1409 "dds.tab.cc" /* yacc.c:1646  */
+#line 1415 "dds.tab.cc" /* yacc.c:1646  */
     break;
 
   case 7:
-#line 179 "dds.yy" /* yacc.c:1646  */
+#line 185 "dds.yy" /* yacc.c:1646  */
     {
-		    parse_error((parser_arg *)arg, NO_DDS_MSG,
- 				dds_line_num, (yyvsp[0].word));
+		    parse_error((parser_arg *)arg, NO_DDS_MSG, dds_line_num, (yyvsp[0].word));
 		    error_exit_cleanup();
 		    YYABORT;
 		}
-#line 1420 "dds.tab.cc" /* yacc.c:1646  */
+#line 1425 "dds.tab.cc" /* yacc.c:1646  */
     break;
 
   case 8:
-#line 188 "dds.yy" /* yacc.c:1646  */
+#line 193 "dds.yy" /* yacc.c:1646  */
     {
 		    (yyval.boolean) = true;
 		}
-#line 1428 "dds.tab.cc" /* yacc.c:1646  */
+#line 1433 "dds.tab.cc" /* yacc.c:1646  */
     break;
 
   case 9:
-#line 192 "dds.yy" /* yacc.c:1646  */
+#line 196 "dds.yy" /* yacc.c:1646  */
     { (yyval.boolean) = true; }
-#line 1434 "dds.tab.cc" /* yacc.c:1646  */
+#line 1439 "dds.tab.cc" /* yacc.c:1646  */
     break;
 
   case 10:
-#line 193 "dds.yy" /* yacc.c:1646  */
+#line 197 "dds.yy" /* yacc.c:1646  */
     { (yyval.boolean) = true; }
-#line 1440 "dds.tab.cc" /* yacc.c:1646  */
+#line 1445 "dds.tab.cc" /* yacc.c:1646  */
     break;
 
   case 11:
-#line 201 "dds.yy" /* yacc.c:1646  */
+#line 207 "dds.yy" /* yacc.c:1646  */
     { 
 		    string smsg;
 		    if (current->check_semantics(smsg)) {
-			/* BaseType *current_save = current ; */
-			add_entry(*DDS_OBJ(arg), &ctor, &current, part); 
-			/* FIX
-			if( current_save == current )
-			{
-			    delete current ;
-			    current = 0 ;
-			}
-			*/
+			    add_entry(*DDS_OBJ(arg), &ctor, &current, part); 
 		    } else {
 		      invalid_declaration((parser_arg *)arg, smsg, (yyvsp[-2].word), (yyvsp[-1].word));
 		      error_exit_cleanup();
 		      YYABORT;
 		    }
-                    strncpy((yyval.word),(yyvsp[-1].word),ID_MAX);
-                    (yyval.word)[ID_MAX-1] = '\0';
+            strncpy((yyval.word),(yyvsp[-1].word),ID_MAX);
+            (yyval.word)[ID_MAX-1] = '\0';
 		}
-#line 1465 "dds.tab.cc" /* yacc.c:1646  */
+#line 1462 "dds.tab.cc" /* yacc.c:1646  */
     break;
 
   case 12:
-#line 223 "dds.yy" /* yacc.c:1646  */
+#line 221 "dds.yy" /* yacc.c:1646  */
     { 
 		    if( current ) delete current ;
 		    current = ctor->top(); 
 		    ctor->pop();
 		}
-#line 1475 "dds.tab.cc" /* yacc.c:1646  */
+#line 1472 "dds.tab.cc" /* yacc.c:1646  */
     break;
 
   case 13:
-#line 229 "dds.yy" /* yacc.c:1646  */
+#line 227 "dds.yy" /* yacc.c:1646  */
     { 
 		    string smsg;
-		    if (current->check_semantics(smsg))
-			add_entry(*DDS_OBJ(arg), &ctor, &current, part); 
+		    if (current->check_semantics(smsg)) {
+			    add_entry(*DDS_OBJ(arg), &ctor, &current, part); 
+			}
 		    else {
-		      invalid_declaration((parser_arg *)arg, smsg, (yyvsp[-6].word), (yyvsp[-1].word));
-		      error_exit_cleanup();
-		      YYABORT;
+		        invalid_declaration((parser_arg *)arg, smsg, (yyvsp[-6].word), (yyvsp[-1].word));
+		        error_exit_cleanup();
+		        YYABORT;
 		    }
-                    strncpy((yyval.word),(yyvsp[-1].word),ID_MAX);
-                    (yyval.word)[ID_MAX-1] = '\0';
+            strncpy((yyval.word),(yyvsp[-1].word),ID_MAX);
+            (yyval.word)[ID_MAX-1] = '\0';
 		}
-#line 1492 "dds.tab.cc" /* yacc.c:1646  */
+#line 1490 "dds.tab.cc" /* yacc.c:1646  */
     break;
 
   case 14:
-#line 243 "dds.yy" /* yacc.c:1646  */
+#line 242 "dds.yy" /* yacc.c:1646  */
     { 
 		    if( current ) delete current ;
 		    current = ctor->top(); 
 		    ctor->pop();
 		}
-#line 1502 "dds.tab.cc" /* yacc.c:1646  */
+#line 1500 "dds.tab.cc" /* yacc.c:1646  */
     break;
 
   case 15:
-#line 249 "dds.yy" /* yacc.c:1646  */
+#line 248 "dds.yy" /* yacc.c:1646  */
     { 
 		    string smsg;
-		    if (current->check_semantics(smsg))
-			add_entry(*DDS_OBJ(arg), &ctor, &current, part); 
+		    if (current->check_semantics(smsg)) {
+			    add_entry(*DDS_OBJ(arg), &ctor, &current, part); 
+			}
 		    else {
 		      invalid_declaration((parser_arg *)arg, smsg, (yyvsp[-6].word), (yyvsp[-1].word));
 		      error_exit_cleanup();
 		      YYABORT;
 		    }
-                    strncpy((yyval.word),(yyvsp[-1].word),ID_MAX);
-                    (yyval.word)[ID_MAX-1] = '\0';
+            strncpy((yyval.word),(yyvsp[-1].word),ID_MAX);
+            (yyval.word)[ID_MAX-1] = '\0';
 		}
-#line 1519 "dds.tab.cc" /* yacc.c:1646  */
+#line 1518 "dds.tab.cc" /* yacc.c:1646  */
     break;
 
   case 16:
 #line 263 "dds.yy" /* yacc.c:1646  */
     { 
-		    if (is_keyword(string((yyvsp[-1].word)), "array"))
-			part = array; 
+		    if (is_keyword(string((yyvsp[-1].word)), "array")) {
+			    part = array;
+			}
 		    else {
-			ostringstream msg;
-			msg << BAD_DECLARATION;
-			parse_error((parser_arg *)arg, msg.str().c_str(),
-				    dds_line_num, (yyvsp[-1].word));
-			YYABORT;
+			    ostringstream msg;
+			    msg << BAD_DECLARATION;
+			    parse_error((parser_arg *)arg, msg.str().c_str(), dds_line_num, (yyvsp[-1].word));
+			    YYABORT;
 		    }
-                }
-#line 1535 "dds.tab.cc" /* yacc.c:1646  */
+        }
+#line 1534 "dds.tab.cc" /* yacc.c:1646  */
     break;
 
   case 17:
 #line 275 "dds.yy" /* yacc.c:1646  */
     { 
-		    if (is_keyword(string((yyvsp[-1].word)), "maps"))
-			part = maps; 
+		    if (is_keyword(string((yyvsp[-1].word)), "maps")) {
+			    part = maps; 
+			}
 		    else {
-			ostringstream msg;
-			msg << BAD_DECLARATION;
-			parse_error((parser_arg *)arg, msg.str().c_str(),
-				    dds_line_num, (yyvsp[-1].word));
-			YYABORT;
+			    ostringstream msg;
+			    msg << BAD_DECLARATION;
+			    parse_error((parser_arg *)arg, msg.str().c_str(), dds_line_num, (yyvsp[-1].word));
+			    YYABORT;
 		    }
-                }
-#line 1551 "dds.tab.cc" /* yacc.c:1646  */
+        }
+#line 1550 "dds.tab.cc" /* yacc.c:1646  */
     break;
 
   case 18:
@@ -1557,7 +1556,7 @@ yyreduce:
 		    current = ctor->top(); 
 		    ctor->pop();
 		}
-#line 1561 "dds.tab.cc" /* yacc.c:1646  */
+#line 1560 "dds.tab.cc" /* yacc.c:1646  */
     break;
 
   case 19:
@@ -1565,18 +1564,18 @@ yyreduce:
     {
 		    string smsg;
 		    if (current->check_semantics(smsg)) {
-			part = nil; 
-			add_entry(*DDS_OBJ(arg), &ctor, &current, part); 
+			    part = nil; 
+			    add_entry(*DDS_OBJ(arg), &ctor, &current, part); 
 		    }
 		    else {
 		      invalid_declaration((parser_arg *)arg, smsg, (yyvsp[-13].word), (yyvsp[-1].word));
 		      error_exit_cleanup();
 		      YYABORT;
 		    }
-                    strncpy((yyval.word),(yyvsp[-1].word),ID_MAX);
-                    (yyval.word)[ID_MAX-1] = '\0';
+        strncpy((yyval.word),(yyvsp[-1].word),ID_MAX);
+        (yyval.word)[ID_MAX-1] = '\0';
 		}
-#line 1580 "dds.tab.cc" /* yacc.c:1646  */
+#line 1579 "dds.tab.cc" /* yacc.c:1646  */
     break;
 
   case 20:
@@ -1584,206 +1583,200 @@ yyreduce:
     {
 		    ostringstream msg;
 		    msg << BAD_DECLARATION;
-		    parse_error((parser_arg *)arg, msg.str().c_str(),
-				dds_line_num, (yyvsp[0].word));
+		    parse_error((parser_arg *)arg, msg.str().c_str(), dds_line_num, (yyvsp[0].word));
 		    YYABORT;
 		}
-#line 1592 "dds.tab.cc" /* yacc.c:1646  */
+#line 1590 "dds.tab.cc" /* yacc.c:1646  */
     break;
 
   case 21:
-#line 320 "dds.yy" /* yacc.c:1646  */
+#line 319 "dds.yy" /* yacc.c:1646  */
     { 
 		    ctor->push(DDS_OBJ(arg)->get_factory()->NewStructure()); 
 		}
-#line 1600 "dds.tab.cc" /* yacc.c:1646  */
+#line 1598 "dds.tab.cc" /* yacc.c:1646  */
     break;
 
   case 22:
-#line 326 "dds.yy" /* yacc.c:1646  */
+#line 325 "dds.yy" /* yacc.c:1646  */
     { 
 		    ctor->push(DDS_OBJ(arg)->get_factory()->NewSequence()); 
 		}
-#line 1608 "dds.tab.cc" /* yacc.c:1646  */
+#line 1606 "dds.tab.cc" /* yacc.c:1646  */
     break;
 
   case 23:
-#line 332 "dds.yy" /* yacc.c:1646  */
+#line 331 "dds.yy" /* yacc.c:1646  */
     { 
 		    ctor->push(DDS_OBJ(arg)->get_factory()->NewGrid()); 
 		}
-#line 1616 "dds.tab.cc" /* yacc.c:1646  */
+#line 1614 "dds.tab.cc" /* yacc.c:1646  */
     break;
 
   case 24:
-#line 337 "dds.yy" /* yacc.c:1646  */
+#line 336 "dds.yy" /* yacc.c:1646  */
     { if( current ) delete current ;current = DDS_OBJ(arg)->get_factory()->NewByte(); }
-#line 1622 "dds.tab.cc" /* yacc.c:1646  */
+#line 1620 "dds.tab.cc" /* yacc.c:1646  */
     break;
 
   case 25:
-#line 338 "dds.yy" /* yacc.c:1646  */
+#line 337 "dds.yy" /* yacc.c:1646  */
     { if( current ) delete current ;current = DDS_OBJ(arg)->get_factory()->NewInt16(); }
-#line 1628 "dds.tab.cc" /* yacc.c:1646  */
+#line 1626 "dds.tab.cc" /* yacc.c:1646  */
     break;
 
   case 26:
-#line 339 "dds.yy" /* yacc.c:1646  */
+#line 338 "dds.yy" /* yacc.c:1646  */
     { if( current ) delete current ;current = DDS_OBJ(arg)->get_factory()->NewUInt16(); }
-#line 1634 "dds.tab.cc" /* yacc.c:1646  */
+#line 1632 "dds.tab.cc" /* yacc.c:1646  */
     break;
 
   case 27:
-#line 340 "dds.yy" /* yacc.c:1646  */
+#line 339 "dds.yy" /* yacc.c:1646  */
     { if( current ) delete current ;current = DDS_OBJ(arg)->get_factory()->NewInt32(); }
-#line 1640 "dds.tab.cc" /* yacc.c:1646  */
+#line 1638 "dds.tab.cc" /* yacc.c:1646  */
     break;
 
   case 28:
-#line 341 "dds.yy" /* yacc.c:1646  */
+#line 340 "dds.yy" /* yacc.c:1646  */
     { if( current ) delete current ;current = DDS_OBJ(arg)->get_factory()->NewUInt32(); }
-#line 1646 "dds.tab.cc" /* yacc.c:1646  */
+#line 1644 "dds.tab.cc" /* yacc.c:1646  */
     break;
 
   case 29:
-#line 342 "dds.yy" /* yacc.c:1646  */
+#line 341 "dds.yy" /* yacc.c:1646  */
     { if( current ) delete current ;current = DDS_OBJ(arg)->get_factory()->NewFloat32(); }
-#line 1652 "dds.tab.cc" /* yacc.c:1646  */
+#line 1650 "dds.tab.cc" /* yacc.c:1646  */
     break;
 
   case 30:
-#line 343 "dds.yy" /* yacc.c:1646  */
+#line 342 "dds.yy" /* yacc.c:1646  */
     { if( current ) delete current ;current = DDS_OBJ(arg)->get_factory()->NewFloat64(); }
-#line 1658 "dds.tab.cc" /* yacc.c:1646  */
+#line 1656 "dds.tab.cc" /* yacc.c:1646  */
     break;
 
   case 31:
-#line 344 "dds.yy" /* yacc.c:1646  */
+#line 343 "dds.yy" /* yacc.c:1646  */
     { if( current ) delete current ;current = DDS_OBJ(arg)->get_factory()->NewStr(); }
-#line 1664 "dds.tab.cc" /* yacc.c:1646  */
+#line 1662 "dds.tab.cc" /* yacc.c:1646  */
     break;
 
   case 32:
-#line 345 "dds.yy" /* yacc.c:1646  */
+#line 344 "dds.yy" /* yacc.c:1646  */
     { if( current ) delete current ;current = DDS_OBJ(arg)->get_factory()->NewUrl(); }
-#line 1670 "dds.tab.cc" /* yacc.c:1646  */
+#line 1668 "dds.tab.cc" /* yacc.c:1646  */
     break;
 
   case 33:
-#line 348 "dds.yy" /* yacc.c:1646  */
+#line 347 "dds.yy" /* yacc.c:1646  */
     { current->set_name((yyvsp[0].word)); }
-#line 1676 "dds.tab.cc" /* yacc.c:1646  */
+#line 1674 "dds.tab.cc" /* yacc.c:1646  */
     break;
 
   case 49:
-#line 359 "dds.yy" /* yacc.c:1646  */
+#line 358 "dds.yy" /* yacc.c:1646  */
     { 
-		     if (!check_int32((yyvsp[-1].word))) {
-			 string msg = "In the dataset descriptor object:\n";
-			 msg += "Expected an array subscript.\n";
-			 parse_error((parser_arg *)arg, msg.c_str(), 
-				 dds_line_num, (yyvsp[-1].word));
-		     }
-		     if (current->type() == dods_array_c
-			 && check_int32((yyvsp[-1].word))) {
-			 ((Array *)current)->append_dim(atoi((yyvsp[-1].word)));
-		     }
-		     else {
-			 Array *a = DDS_OBJ(arg)->get_factory()->NewArray(); 
-			 a->add_var(current); 
-			 a->append_dim(atoi((yyvsp[-1].word)));
-			 if( current ) delete current ;
-			 current = a;
-		     }
+		    if (!check_int32((yyvsp[-1].word))) {
+			    string msg = "In the dataset descriptor object:\n";
+			    msg += "Expected an array subscript.\n";
+			    parse_error((parser_arg *)arg, msg.c_str(), dds_line_num, (yyvsp[-1].word));
+		    }
+		    if (current->type() == dods_array_c && check_int32((yyvsp[-1].word))) {
+			    ((Array *)current)->append_dim(atoi((yyvsp[-1].word)));
+		    }
+		    else {
+			    Array *a = DDS_OBJ(arg)->get_factory()->NewArray(); 
+			    a->add_var(current); 
+			    a->append_dim(atoi((yyvsp[-1].word)));
+			    if( current ) delete current ;
+			    current = a;
+		    }
 
-		     (yyval.boolean) = true;
+		    (yyval.boolean) = true;
 		 }
-#line 1702 "dds.tab.cc" /* yacc.c:1646  */
+#line 1698 "dds.tab.cc" /* yacc.c:1646  */
     break;
 
   case 50:
-#line 382 "dds.yy" /* yacc.c:1646  */
+#line 379 "dds.yy" /* yacc.c:1646  */
     {
-		     id = new string((yyvsp[0].word));
+		     if (!id) id = new string((yyvsp[0].word));
 		 }
-#line 1710 "dds.tab.cc" /* yacc.c:1646  */
+#line 1706 "dds.tab.cc" /* yacc.c:1646  */
     break;
 
   case 51:
-#line 386 "dds.yy" /* yacc.c:1646  */
+#line 383 "dds.yy" /* yacc.c:1646  */
     { 
 		     if (!check_int32((yyvsp[0].word))) {
-			 string msg = "In the dataset descriptor object:\n";
-			 msg += "Expected an array subscript.\n";
-			 parse_error((parser_arg *)arg, msg.c_str(), 
-				 dds_line_num, (yyvsp[0].word));
-			 error_exit_cleanup();
-			 YYABORT;
+			     string msg = "In the dataset descriptor object:\n";
+			     msg += "Expected an array subscript.\n";
+			     parse_error((parser_arg *)arg, msg.c_str(), dds_line_num, (yyvsp[0].word));
+			     error_exit_cleanup();
+			     YYABORT;
 		     }
 		     if (current->type() == dods_array_c) {
-			 ((Array *)current)->append_dim(atoi((yyvsp[0].word)), *id);
+			     ((Array *)current)->append_dim(atoi((yyvsp[0].word)), *id);
 		     }
 		     else {
-			 Array *a = DDS_OBJ(arg)->get_factory()->NewArray(); 
-			 a->add_var(current); 
-			 a->append_dim(atoi((yyvsp[0].word)), *id);
-			 if( current ) delete current ;
-			 current = a;
+			     Array *a = DDS_OBJ(arg)->get_factory()->NewArray(); 
+			     a->add_var(current); 
+			     a->append_dim(atoi((yyvsp[0].word)), *id);
+			     if( current ) delete current ;
+			     current = a;
 		     }
 
 		     delete id; id = 0;
 		 }
-#line 1737 "dds.tab.cc" /* yacc.c:1646  */
+#line 1732 "dds.tab.cc" /* yacc.c:1646  */
     break;
 
   case 52:
-#line 409 "dds.yy" /* yacc.c:1646  */
+#line 405 "dds.yy" /* yacc.c:1646  */
     {
 		     (yyval.boolean) = true;
 		 }
-#line 1745 "dds.tab.cc" /* yacc.c:1646  */
+#line 1740 "dds.tab.cc" /* yacc.c:1646  */
     break;
 
   case 53:
-#line 414 "dds.yy" /* yacc.c:1646  */
+#line 410 "dds.yy" /* yacc.c:1646  */
     {
 		     ostringstream msg;
 		     msg << "In the dataset descriptor object:" << endl
-			 << "Expected an array subscript." << endl;
-		     parse_error((parser_arg *)arg, msg.str().c_str(), 
-				 dds_line_num, (yyvsp[0].word));
+			     << "Expected an array subscript." << endl;
+		     parse_error((parser_arg *)arg, msg.str().c_str(), dds_line_num, (yyvsp[0].word));
 		     YYABORT;
 		 }
-#line 1758 "dds.tab.cc" /* yacc.c:1646  */
+#line 1752 "dds.tab.cc" /* yacc.c:1646  */
     break;
 
   case 54:
-#line 424 "dds.yy" /* yacc.c:1646  */
-    { (*DDS_OBJ(arg)).set_dataset_name((yyvsp[0].word)); }
-#line 1764 "dds.tab.cc" /* yacc.c:1646  */
+#line 419 "dds.yy" /* yacc.c:1646  */
+    { (*DDS_OBJ(arg)).set_dataset_name((yyvsp[0].word)); (yyval.boolean) = true;}
+#line 1758 "dds.tab.cc" /* yacc.c:1646  */
     break;
 
   case 55:
-#line 425 "dds.yy" /* yacc.c:1646  */
-    { (*DDS_OBJ(arg)).set_dataset_name((yyvsp[0].word)); }
-#line 1770 "dds.tab.cc" /* yacc.c:1646  */
+#line 420 "dds.yy" /* yacc.c:1646  */
+    { (*DDS_OBJ(arg)).set_dataset_name((yyvsp[0].word)); (yyval.boolean) = true; }
+#line 1764 "dds.tab.cc" /* yacc.c:1646  */
     break;
 
   case 56:
-#line 427 "dds.yy" /* yacc.c:1646  */
+#line 422 "dds.yy" /* yacc.c:1646  */
     {
-		  ostringstream msg;
-		  msg << "Error parsing the dataset name." << endl
-		      << "The name may be missing or may contain an illegal character." << endl;
-		     parse_error((parser_arg *)arg, msg.str().c_str(),
-				 dds_line_num, (yyvsp[0].word));
-		     YYABORT;
+		    ostringstream msg;
+		    msg << "Error parsing the dataset name." << endl
+		        << "The name may be missing or may contain an illegal character." << endl;
+		    parse_error((parser_arg *)arg, msg.str().c_str(), dds_line_num, (yyvsp[0].word));
+		    YYABORT;
 		}
-#line 1783 "dds.tab.cc" /* yacc.c:1646  */
+#line 1776 "dds.tab.cc" /* yacc.c:1646  */
     break;
 
 
-#line 1787 "dds.tab.cc" /* yacc.c:1646  */
+#line 1780 "dds.tab.cc" /* yacc.c:1646  */
       default: break;
     }
   /* User semantic actions sometimes alter yychar, and that requires
@@ -2011,7 +2004,7 @@ yyreturn:
 #endif
   return yyresult;
 }
-#line 437 "dds.yy" /* yacc.c:1906  */
+#line 431 "dds.yy" /* yacc.c:1906  */
 
 
 /* 
