@@ -301,7 +301,7 @@ main(int argc, char *argv[])
 
     // process options
 
-    while ((option_char = getopt()) != EOF)
+    while ((option_char = getopt()) != -1)
         switch (option_char) {
         case 'p':
             parse = true;
