@@ -348,9 +348,9 @@ int
 main(int argc, char *argv[])
 {
     GetOpt getopt(argc, argv, "d");
-    char option_char;
+    int option_char;
 
-    while ((option_char = getopt()) != EOF)
+    while ((option_char = getopt()) != -1)
         switch (option_char) {
             case 'd':
                 debug = 1;  // debug is a static global
